from django.db import models


class Blacklist(models.Model):
    email = models.EmailField(unique=True)
    type = models.PositiveSmallIntegerField(default=0)
    created_at = models.DateTimeField(auto_now_add=True)

    def __unicode__(self):
        return self.email


RESULT_CODES = (
    ("1", "success"),
    ("2", "retry"),
    ("3", "blacklisted"),
)

class MessageLogManager(models.Manager):
    def log(self, message, result_code):
        self.create(email=message.to[0], body=message.message(), result=result_code)
        

class MessageLog(models.Model):
    email = models.EmailField()
    body = models.TextField()
    result = models.CharField(max_length=1, choices=RESULT_CODES)
    created_at = models.DateTimeField(auto_now_add=True)

    objects = MessageLogManager()

    def __unicode__(self):
        return self.email



# coding: utf-8

from django.http import HttpResponse
from django.utils import simplejson
from django.utils.simplejson import JSONDecodeError
from django.views.decorators.csrf import csrf_exempt

from svcelery_email.models import Blacklist


@csrf_exempt
def sns_notification(request):
    """
    Receive AWS SES bounce SNS notification
    """

    # decode json
    try:
        json = request.raw_post_data
        data = simplejson.loads(json)
    except JSONDecodeError:
        return HttpResponse('Oops')

    try:
        message = simplejson.loads(data['Message'])
    except ValueError:
        assert False, request.raw_post_data

    #
    type = 0 if message['notificationType'] == 'Bounce' else 1
    email = message['mail']['destination'][0]


    # add email to blacklist
    try:
        Blacklist.objects.get(email=email)
    except Blacklist.DoesNotExist:
        Blacklist.objects.create(email=email, type=type)

    return HttpResponse('Done')



from django.contrib import admin
from svcelery_email.models import Blacklist, MessageLog

class BlacklistAdmin(admin.ModelAdmin):
    pass
admin.site.register(Blacklist, BlacklistAdmin)

class MessageLogAdmin(admin.ModelAdmin):
    list_display = ('email', 'result', 'created_at')
admin.site.register(MessageLog, MessageLogAdmin)



from setuptools import setup, find_packages
from djcelery_ses import __version__


setup(
    name='django-celery-ses',
    version=__version__,
    description="django-celery-ses",
    classifiers=[
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Framework :: Django",
        "Environment :: Web Environment",
    ],
    keywords='django,celery,mail',
    author='tzangms',
    author_email='tzangms@streetvoice.com',
    url='http://github.com/StreetVoice/django-celery-ses',
    license='MIT',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
)
